@@ -9,5 +9,12 @@ SELECT * FROM ts_debug('japanese', E'日\n本\n語\n文\n字\n中\nの\n改\n行
 SELECT * FROM ts_debug('japanese', E'Line\nbreaks\nin\nEnglish\ntext\nare\nreserved.');
 SELECT * FROM ts_debug('japanese', '日本語とEnglishがmixedな文も解析OKです。');
 
-SELECT to_tsvector('japanese', '語尾は基本形に戻されます。');
-SELECT to_tsvector('japanese', 'ユーザとユーザーは正規化されます。ミラーとミラは別扱い。');
+SELECT s
+  FROM regexp_split_to_table(to_tsvector('japanese',
+		'語尾は基本形に戻されます。')::text, ' ') AS t(s)
+ ORDER BY s;
+
+SELECT s
+  FROM regexp_split_to_table(to_tsvector('japanese',
+		'ユーザとユーザーは正規化されます。ミラーとミラは別扱い。')::text, ' ') AS t(s)
+ ORDER BY s;
