@@ -1,7 +1,5 @@
 /*
  * textsearch_ja.h
- *
- *	Copyright (c) 2008-2009, NIPPON TELEGRAPH AND TELEPHONE CORPORATION
  */
 #ifndef TEXTSEARCH_JA_H
 #define TEXTSEARCH_JA_H
@@ -31,12 +29,6 @@ extern const IgnorableWord	IGNORE_EUCJP[];
 #define StringInfoTail(str, at) \
 	((unsigned char *) ((str)->data + (str)->len - (at)))
 
-#if PG_VERSION_NUM < 80400
-extern text *cstring_to_text_with_len(const char *s, int n);
-extern text *cstring_to_text(const char *s);
-#define CStringGetTextDatum(s) PointerGetDatum(cstring_to_text(s))
-#endif
-
 #define uchar_mblen(ustr)				pg_mblen((const char *) (ustr))
 #define uchar_strlen(ustr)				strlen((const char *) (ustr))
 #define appendMBString(dst, ustr, len)	appendBinaryStringInfo((dst), (const char *) (ustr), (len))
